@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 Drew Noakes
+ * Copyright 2002-2015 Drew Noakes
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
  *
  * More information about this project is available at:
  *
- *    http://drewnoakes.com/code/exif/
- *    http://code.google.com/p/metadata-extractor/
+ *    https://drewnoakes.com/code/exif/
+ *    https://github.com/drewnoakes/metadata-extractor
  */
 package com.drew.lang;
 
@@ -26,7 +26,7 @@ import java.io.OutputStream;
 /**
  * An implementation of OutputSteam that ignores write requests by doing nothing.  This class may be useful in tests.
  *
- * @author Drew Noakes http://drewnoakes.com
+ * @author Drew Noakes https://drewnoakes.com
  */
 public class NullOutputStream extends OutputStream
 {
@@ -35,6 +35,7 @@ public class NullOutputStream extends OutputStream
         super();
     }
 
+    @Override
     public void write(int b) throws IOException
     {
         // do nothing
