@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 Drew Noakes
+ * Copyright 2002-2015 Drew Noakes
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
  *
  * More information about this project is available at:
  *
- *    http://drewnoakes.com/code/exif/
- *    http://code.google.com/p/metadata-extractor/
+ *    https://drewnoakes.com/code/exif/
+ *    https://github.com/drewnoakes/metadata-extractor
  */
 package com.drew.metadata.jpeg;
 
@@ -25,9 +25,9 @@ import com.drew.lang.annotations.Nullable;
 import com.drew.metadata.TagDescriptor;
 
 /**
- * Provides human-readable string representations of tag values stored in a <code>JpegCommentDirectory</code>.
+ * Provides human-readable string representations of tag values stored in a {@link JpegCommentDirectory}.
  *
- * @author Drew Noakes http://drewnoakes.com
+ * @author Drew Noakes https://drewnoakes.com
  */
 public class JpegCommentDescriptor extends TagDescriptor<JpegCommentDirectory>
 {
@@ -39,6 +39,6 @@ public class JpegCommentDescriptor extends TagDescriptor<JpegCommentDirectory>
     @Nullable
     public String getJpegCommentDescription()
     {
-        return _directory.getString(JpegCommentDirectory.TAG_JPEG_COMMENT);
+        return _directory.getString(JpegCommentDirectory.TAG_COMMENT);
     }
 }
